aboutsummaryrefslogtreecommitdiff
path: root/include/llvm/CodeGen/MachineRelocation.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/CodeGen/MachineRelocation.h')
-rw-r--r--include/llvm/CodeGen/MachineRelocation.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/include/llvm/CodeGen/MachineRelocation.h b/include/llvm/CodeGen/MachineRelocation.h
index 5c8302a56f..9a812a1fad 100644
--- a/include/llvm/CodeGen/MachineRelocation.h
+++ b/include/llvm/CodeGen/MachineRelocation.h
@@ -39,7 +39,7 @@ class MachineRelocation {
enum AddressType {
isResult, // Relocation has be transformed into its result pointer.
isGV, // The Target.GV field is valid.
- isGVLazyPtr, // Relocation of a lazily resolved GV address.
+ isGVNonLazyPtr, // Relocation of a Mac OS X NonLazy indirect reference.
isBB, // Relocation of BB address.
isExtSym, // The Target.ExtSym field is valid.
isConstPool, // Relocation of constant pool address.
@@ -56,7 +56,7 @@ class MachineRelocation {
union {
void *Result; // If this has been resolved to a resolved pointer
- GlobalValue *GV; // If this is a pointer to a GV or a GV lazy ptr
+ GlobalValue *GV; // If this is a pointer to a GV or a GV nonlazy ptr
MachineBasicBlock *MBB; // If this is a pointer to a LLVM BB
const char *ExtSym; // If this is a pointer to a named symbol
unsigned Index; // Constant pool / jump table index
@@ -96,9 +96,9 @@ public:
return Result;
}
- /// MachineRelocation::getGVLazyPtr - Return a relocation entry for a
- /// lazily resolved GlobalValue address.
- static MachineRelocation getGVLazyPtr(intptr_t offset,
+ /// MachineRelocation::getGVNonLazyPtr - Return a relocation entry for a
+ /// Mac OS X non-lazy GlobalValue indirect reference.
+ static MachineRelocation getGVNonLazyPtr(intptr_t offset,
unsigned RelocationType,
GlobalValue *GV, intptr_t cst = 0,
bool NeedStub = 0,
@@ -108,7 +108,7 @@ public:
Result.Offset = offset;
Result.ConstantVal = cst;
Result.TargetReloType = RelocationType;
- Result.AddrType = isGVLazyPtr;
+ Result.AddrType = isGVNonLazyPtr;
Result.NeedStub = NeedStub;
Result.GOTRelative = GOTrelative;
Result.TargetResolve = false;
@@ -221,10 +221,10 @@ public:
return AddrType == isGV;
}
- /// isGlobalValueVLazyPtr - Return true if this relocation is the address
- /// of a lazily resolved GlobalValue.
- bool isGlobalValueLazyPtr() const {
- return AddrType == isGVLazyPtr;
+ /// isGlobalValueNonLazyPtr - Return true if this relocation is the address
+ /// of a Mac OS X non-lazy indirect reference.
+ bool isGlobalValueNonLazyPtr() const {
+ return AddrType == isGVNonLazyPtr;
}
/// isBasicBlock - Return true if this relocation is a basic block reference.
@@ -274,7 +274,7 @@ public:
/// getGlobalValue - If this is a global value reference, return the
/// referenced global.
GlobalValue *getGlobalValue() const {
- assert((isGlobalValue() || isGlobalValueLazyPtr()) &&
+ assert((isGlobalValue() || isGlobalValueNonLazyPtr()) &&
"This is not a global value reference!");
return Target.GV;
}